import { Observable } from 'rxjs';
import { OBDConnection } from './OBDConnection';
/**
 * The wrapper of Socket for Cordova plugin Socket For Cordova.
 */
export declare class CordovaOBDConnection extends OBDConnection {
    /**
     * Wrapped Cordova Socket instance.
     */
    private socket;
    /**
     * Subject of data incomming from OBD Reader connection.
     */
    private data$;
    /**
     * Open connection to OBD Reader.
     * @returns the observable of opening connection.
     */
    open(config: {
        host: string;
        port: number;
    }): Observable<any>;
    /**
     * Send a command to OBD Reader.
     * @returns the observable of send operation.
     * The events emitted are ignored, wait for complete (successful) or error (failure).
     */
    send(command: string): Observable<any>;
    /**
     * Listener for data received from OBD Reader.
     * @returns Observable of data received from OBD Reader.
     */
    onData(): Observable<string>;
    /**
     * Close and dispose resources of OBD Reader connection.
     * @returns the observable of close operation.
     * The events emitted are ignored, wait for complete (successful) or error (failure).
     */
    close(): Observable<any>;
    /**
     * Marshall the string data into bytes array.
     * @param data the string data.
     * @returns the bytes array.
     */
    static marshall(data: string): Uint8Array;
    /**
     * Unmarshall the bytes array into data string.
     * @param bytes the bytes array.
     * @returns the string data.
     */
    static unmarshall(bytes: Uint8Array): string;
}
