"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var rxjs_1 = require("rxjs");
var connection_1 = require("../connection");
var OBDEvent_1 = require("../model/OBDEvent");
exports.fromOBD2 = function (config) {
    if (config === void 0) { config = connection_1.defaultOBDWifiConfig; }
    return new rxjs_1.Observable(function (subscriber) {
        /**
         * The connection connection to ELM 327 OBD Reader.
         */
        var pullingInterval = config.pullingInterval, connection = config.connection;
        /**
         * Last OBD Data emitted.
         */
        var data;
        /**
         * Flag of indicate that a pull loop is running.
         */
        var running = false;
        /**
         * Internal pulling (interval) subscription.
         */
        var subscription;
        /**
         * Subject to observe the pluck moment.
         */
        var subject = new rxjs_1.Subject();
        subject.subscribe(function (value) {
            data = __assign({}, value);
            running = false;
        });
        var dispatchNext = function (id, subscriber) {
            if (!running) {
                running = true;
                subscriber.next(new OBDEvent_1.OBDEvent(id, connection, subject, __assign({}, data)));
            }
        };
        connection.open(config).subscribe({
            error: function (error) { return subscriber.error(error); },
            complete: function () {
                // connected
                subscription = rxjs_1.interval(pullingInterval).subscribe(function (id) { return dispatchNext(id, subscriber); });
            }
        });
        return function () {
            if (!!connection) {
                connection.close();
            }
            if (!!subscription) {
                subscription.unsubscribe();
            }
        };
    });
};
//# sourceMappingURL=fromOBD2.js.map