import { OBDOuterSubscriber } from '../model/OBDOuterSubscriber';
export function fuelSystemStatus() {
    return function (source) {
        return source.lift(new FuelSystemStatusOperator());
    };
}
class FuelSystemStatusOperator {
    call(subscriber, source) {
        return source.subscribe(new FuelSystemStatusSubscriber(subscriber));
    }
}
class FuelSystemStatusSubscriber extends OBDOuterSubscriber {
    constructor(destination) {
        super(destination);
    }
    /**
     * Return the frequency of execution of this command.
     * @return that this command must be executed every pulse.
     */
    pulse() {
        return 1;
    }
    /**
     * Return the string representation of the OBD Read command.
     * @returns the string representation of the OBD Read command
     */
    command() {
        return '01 03 1\r';
    }
    /**
     * Return the name of the OBD Field on OBD Data object.
     * @returns the name of the OBD Field on OBD Data object.
     */
    field() {
        return 'fuelSystemStatus';
    }
    /**
     * Parse the OBD response.
     * @param bytes the response read from OBD.
     * @returns the parsed response.
     */
    parse(bytes) {
        return `${bytes[2]} ${bytes[3]}`;
    }
}
//# sourceMappingURL=fuelSystemStatus.js.map