import { OBDOuterSubscriber } from '../model/OBDOuterSubscriber';
export function distanceTraveled() {
    return function (source) {
        return source.lift(new DistanceTraveledOperator());
    };
}
class DistanceTraveledOperator {
    call(subscriber, source) {
        return source.subscribe(new DistanceTraveledSubscriber(subscriber));
    }
}
class DistanceTraveledSubscriber extends OBDOuterSubscriber {
    constructor(destination) {
        super(destination);
    }
    /**
     * Return the frequency of execution of this command.
     * @return that this command must be executed every pulse.
     */
    pulse() {
        return 1;
    }
    /**
     * Return the string representation of the OBD Read command.
     * @returns the string representation of the OBD Read command
     */
    command() {
        return '01 31 1\r';
    }
    /**
     * Return the name of the OBD Field on OBD Data object.
     * @returns the name of the OBD Field on OBD Data object.
     */
    field() {
        return 'distanceTraveled';
    }
    /**
     * Parse the OBD response.
     * @param bytes the response read from OBD.
     * @returns the parsed response.
     */
    parse(bytes) {
        return (parseInt(bytes[2], 16) * 256) + parseInt(bytes[3], 16);
    }
}
//# sourceMappingURL=distanceTraveled.js.map