import { OBDOuterSubscriber } from '../model/OBDOuterSubscriber';
export function distanceTraveledMil() {
    return function (source) {
        return source.lift(new DistanceTraveledMILOperator());
    };
}
class DistanceTraveledMILOperator {
    call(subscriber, source) {
        return source.subscribe(new DistanceTraveledMILSubscriber(subscriber));
    }
}
class DistanceTraveledMILSubscriber extends OBDOuterSubscriber {
    constructor(destination) {
        super(destination);
    }
    /**
     * Return the frequency of execution of this command.
     * @return that this command must be executed every pulse.
     */
    pulse() {
        return 1;
    }
    /**
     * Return the string representation of the OBD Read command.
     * @returns the string representation of the OBD Read command
     */
    command() {
        return '01 21 1\r';
    }
    /**
     * Return the name of the OBD Field on OBD Data object.
     * @returns the name of the OBD Field on OBD Data object.
     */
    field() {
        return 'distanceTraveledMil';
    }
    /**
     * Parse the OBD response.
     * @param bytes the response read from OBD.
     * @returns the parsed response.
     */
    parse(bytes) {
        return (parseInt(bytes[2], 16) * 256) + parseInt(bytes[3], 16);
    }
}
//# sourceMappingURL=distanceTraveledMIL.js.map