import { OBDOuterSubscriber } from '../model/OBDOuterSubscriber';
export function ethanolLevel() {
    return function (source) {
        return source.lift(new EthanolLevelOperator());
    };
}
class EthanolLevelOperator {
    call(subscriber, source) {
        return source.subscribe(new EthanolLevelSubscriber(subscriber));
    }
}
class EthanolLevelSubscriber extends OBDOuterSubscriber {
    constructor(destination) {
        super(destination);
    }
    /**
     * Return the frequency of execution of this command.
     * @return that this command must be executed every 5 pulses.
     */
    pulse() {
        return 5;
    }
    /**
     * Return the string representation of the OBD Read command.
     * @returns the string representation of the OBD Read command
     */
    command() {
        return '01 52 1\r';
    }
    /**
     * Return the name of the OBD Field on OBD Data object.
     * @returns the name of the OBD Field on OBD Data object.
     */
    field() {
        return 'ethanolLevel';
    }
    /**
     * Parse the OBD response.
     * @param bytes the response read from OBD.
     * @returns the parsed response.
     */
    parse(bytes) {
        return parseInt(bytes[2], 16) * 100 / 255;
    }
}
//# sourceMappingURL=ethanolLevel.js.map