import { OBDOuterSubscriber } from '../model/OBDOuterSubscriber';
export function throttlePosition() {
    return function (source) {
        return source.lift(new ThrottlePositionOperator());
    };
}
class ThrottlePositionOperator {
    call(subscriber, source) {
        return source.subscribe(new ThrottlePositionSubscriber(subscriber));
    }
}
class ThrottlePositionSubscriber extends OBDOuterSubscriber {
    constructor(destination) {
        super(destination);
    }
    /**
     * Return the frequency of execution of this command.
     * @return that this command must be executed every pulse.
     */
    pulse() {
        return 1;
    }
    /**
     * Return the string representation of the OBD Read command.
     * @returns the string representation of the OBD Read command
     */
    command() {
        return '01 11 1\r';
    }
    /**
     * Return the name of the OBD Field on OBD Data object.
     * @returns the name of the OBD Field on OBD Data object.
     */
    field() {
        return 'throttlePosition';
    }
    /**
     * Parse the OBD response.
     * @param bytes the response read from OBD.
     * @returns the parsed response.
     */
    parse(bytes) {
        return parseInt(bytes[2], 16) * 100 / 255;
    }
}
//# sourceMappingURL=throttlePosition.js.map